"use client"

import { Disclosure, Transition } from "@headlessui/react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faChevronDown, faChevronUp } from "@fortawesome/free-solid-svg-icons";
import HTMLReactParser from "html-react-parser";

interface IAccordionProps {
	title: string;
	body: string
	// | React.ReactNode;
}

const Accordion = (props: IAccordionProps) => {
	return (
		<>
			<Disclosure as={"div"} className={"w-full"} defaultOpen={false}>
				<>
					<Disclosure.Button
						as="div"
						className={"w-full flex items-center justify-between px-4 py-2 cursor-pointer space-x-28"}
					>
						{({ open }) => (
							<>
								<h3 className=" font-black md:text-lg text-rfw-gray">
									{props.title}
								</h3>
								<FontAwesomeIcon
									icon={faChevronDown}
									className={` ${open ? "transition ease-linear rotate-180 " : ""} w-5 h-5`}
								/>
							</>
						)}
					</Disclosure.Button>
				</>

				<Transition
					enter="transition-opacity duration-700 ease-out"
					enterFrom="transform  opacity-0 "
					enterTo="transform  opacity-100"
					leave="transition-opacity duration-150 ease-out"
					leaveFrom="transform  opacity-100"
					leaveTo="transform  opacity-0"

				>
					<Disclosure.Panel>
						<div className="w-full text-regular text-rfw-darkest px-4 py-1 cursor-text ">
							{HTMLReactParser(props.body)}
							<hr className="mt-10 border-rfw-summer " />
						</div>
					</Disclosure.Panel>
				</Transition>
			</Disclosure>
		</>
	);
};

export default Accordion;
